import polars as pl
import pytest
from polars.exceptions import ComputeError
from polars.testing import assert_series_equal

from polars_whichlang import detect_lang


@pytest.fixture
def sample_df():
    yield pl.DataFrame(
        {
            "index": [1, 2, 3, 4, 5],
            "text": ["This is a test.", "이건 테스트야", "Dies ist ein Test", "", " "],
            "lang_code": ["eng", "kor", "deu", "eng", "ita"],
        }
    )


def test_whichlang_dataframe(sample_df):
    df = sample_df.with_columns(predicted=detect_lang("text"))
    assert len(df) == 5
    assert_series_equal(df["lang_code"], df["predicted"], check_names=False)


def test_whichlang_lazyframe(sample_df):
    df = sample_df.lazy().with_columns(predicted=detect_lang("text"))
    assert isinstance(df, pl.LazyFrame)
    df = df.collect()
    assert len(df) == 5
    assert_series_equal(df["lang_code"], df["predicted"], check_names=False)


def test_whichlang_dataframe_error(sample_df):
    with pytest.raises(ComputeError):
        _ = sample_df.with_columns(predicted=detect_lang("index"))


def test_whichlang_lazyframe_error(sample_df):
    df = sample_df.lazy().with_columns(predicted=detect_lang("index"))
    assert isinstance(df, pl.LazyFrame)
    with pytest.raises(ComputeError):
        _ = df.collect()



from __future__ import annotations

from pathlib import Path
from typing import TYPE_CHECKING, Union

import polars as pl
from polars.plugins import register_plugin_function

if TYPE_CHECKING:
    import sys

    if sys.version_info >= (3, 10):
        from typing import TypeAlias
    else:
        from typing_extensions import TypeAlias
    IntoExpr: TypeAlias = Union[pl.Expr, str, pl.Series]

LIB = Path(__file__).parent


def detect_lang(text: IntoExpr) -> pl.Expr:
    return register_plugin_function(
        args=[text],
        plugin_path=LIB,
        function_name="detect_lang",
        is_elementwise=True,
    )


__version__ = "0.1.0"
